import { View, CustomLayoutView, AddChildFromBuilder } from '../core/view';
/**
 * Represents a View that has a single child - content.
 * The View itself does not have visual representation and serves as a placeholder for its content in the logical tree.
 */
export declare class ContentView extends CustomLayoutView implements AddChildFromBuilder {
    private _content;
    /**
     * Gets or sets the single child of the view.
     */
    get content(): View;
    set content(value: View);
    get layoutView(): View;
    get _childrenCount(): number;
    /**
     * Called when the content property has changed.
     * @private
     * @param oldView The previous content.
     * @param newView The new content.
     */
    _onContentChanged(oldView: View, newView: View): void;
    _addChildFromBuilder(name: string, value: any): void;
    eachChildView(callback: (child: View) => boolean): void;
    onMeasure(widthMeasureSpec: number, heightMeasureSpec: number): void;
    onLayout(left: number, top: number, right: number, bottom: number): void;
}
